#[repr(usize)]pub enum Frame {
NoFrame = 0,
ASCIIFrame = 1,
UnicodeFrame = 2,
UnicodeBoldFrame = 3,
UnicodeDoubleUFrame = 4,
UnicodeBlockFrame = 5,
UnicodeShadeFrame = 6,
}Expand description
A decorative frame can be drawn around the bitmap to better indicate where the edges of the bitmap are located.
Much like with the styles, the results are depended on the font used.
The ASCII frame should always work. The Unicode frames are nicer
but support is more spotty.
Variants
NoFrame = 0
ASCIIFrame = 1
UnicodeFrame = 2
UnicodeBoldFrame = 3
UnicodeDoubleUFrame = 4
UnicodeBlockFrame = 5
UnicodeShadeFrame = 6